@@ -17,6 +17,7 @@ public:
     explicit MainWindow(QWidget *parent = 0);
     ~MainWindow();
 
+    QSettings *settings;
 
 public slots:
     void rom_config();
@@ -28,12 +29,16 @@ public slots:
     void set_keys();
 
     void currentRowChanged ( int );
+	void set_rom_dir();
+	void set_bios_dir();
 
 private:
     Ui::MainWindow *ui;
     QStringList roms;
     options *cfg;
     keys *keyopt;
+    QLabel* lbl1;
+    QLabel* lbl2;
 };
 
 #endif // MAINWINDOW_H
