@@ -7,7 +7,9 @@ options::options(QWidget *parent) :
     ui(new Ui::options)
 {
     ui->setupUi(this);
+#ifdef Q_WS_MAEMO_5
     this->setAttribute(Qt::WA_Maemo5StackedWindow);
+#endif
     this->setWindowFlags(this->windowFlags() | Qt::Window);
     connect (ui->checkBox_2,SIGNAL(clicked()),this,SLOT(psx4m_hwa_block()));
 
@@ -34,6 +36,7 @@ options::~options()
 void options::hideEvent(QHideEvent *){
     if (!this->isVisible()){
         QDialog *dlg=new QDialog(this);
+        dlg->setWindowTitle(tr("Confirm"));
         QGridLayout *lay=new QGridLayout(dlg);
         QLabel *lbl=new QLabel(tr("Do you want to save settings?"),dlg);
         lay->addWidget(lbl,1,0,1,2);
@@ -123,7 +126,7 @@ if (value=="")value="scph1001.bin";
                       if (value=="1")ui->checkBox_5->setChecked(true);else ui->checkBox_5->setChecked(false);
                       break;
                  case 12:// pcsx-frameskip
-                      if (ui->comboBox_3->findText(value)!=1)
+                      if (ui->comboBox_3->findText(value)!=-1)
                           ui->comboBox_3->setCurrentIndex(ui->comboBox_3->findText(value));
                       break;
                  case 13:
@@ -199,14 +202,15 @@ void options::createCfg(){
 
         if (ui->checkBox_3->isChecked())current_config<<"-sputhreaded";
         if (ui->comboBox_5->currentText()=="oldgpu")current_config<<"-oldgpu";
-else if (ui->comboBox_5->currentText()=="gpu-gles")current_config<<"-gles";
-else if (ui->comboBox_5->currentText()=="gpu_unai")current_config<<"-unai";
+        else if (ui->comboBox_5->currentText()=="gpu-gles")current_config<<"-gles";
+        else if (ui->comboBox_5->currentText()=="gpu_unai")current_config<<"-unai";
+        else if (ui->comboBox_5->currentText()=="gpu_4all")current_config<<"-4all";
 
         if (ui->checkBox_5->isChecked())
             if (!ui->comboBox_4->currentText().isEmpty() && !bios_path.isEmpty())
                       current_config<<"-bios"<<ui->comboBox_4->currentText()<<"-bdir"<<bios_path;
-        if (ui->comboBox_3->currentIndex()>0)
-        current_config<<"-frameskip"<<QString("%1").arg(ui->comboBox_3->currentIndex());
+        if (ui->comboBox_3->currentIndex()>=0)
+            current_config<<"-frameskip"<<QString("%1").arg(ui->comboBox_3->currentIndex() - 1);
         if (ui->checkBox_17->isChecked())current_config<<"-fullscreen";
         if (ui->checkBox_4->isChecked())current_config<<"-fps";
         if (ui->checkBox_18->isChecked())current_config<<"-cpu";
@@ -227,10 +231,10 @@ else if (ui->comboBox_5->currentText()=="gpu_unai")current_config<<"-unai";
     else
     {
         current_core="psx4m";
-        if (ui->comboBox_2->currentText()!="Disabled")
+        if (ui->comboBox_2->currentText()!="Disabled"){
             if (ui->comboBox_2->currentText()=="Auto")current_config<<"-autoskip";
-                    else current_config<<"-frameskip"<<ui->comboBox_2->currentText();
-
+            else current_config<<"-frameskip"<<ui->comboBox_2->currentText();
+        }
         if (ui->checkBox_6->isChecked())current_config<<"-showfps";
         if (ui->checkBox_7->isChecked())current_config<<"-fullscreen";
         if (ui->checkBox_8->isChecked())current_config<<"-abbeyfix";
@@ -298,7 +302,7 @@ void options::save_cfg(){
 .arg(ui->checkBox_15->isChecked()?"1":"0")
         .arg(ui->checkBox_16->isChecked()?"1":"0")
         .arg(ui->checkBox_17->isChecked()?"1":"0")
-            .arg(ui->checkBox_5->isChecked()?"1":"0")
+            .arg(ui->checkBox_4->isChecked()?"1":"0")
             .arg(ui->checkBox_18->isChecked()?"1":"0")
             .arg(ui->checkBox_19->isChecked()?"1":"0")
 ;
